#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

run "../../nfem/sbin/mkgeo_grid_2d 80 -a -2 -b 2 -c -2 -d 2 > tmp-80.geo 2>/dev/null"
run "./form_ext_s_tst tmp-80.geo 1e-5 > /dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi
run "rm -f tmp-80.geo 2>/dev/null"

exit $status
